# Welcome to HEPBrowse

HEPBrowse is a terminal-based browser for High-Energy Physics data files (`.h5` and `.root`).

## Features

- Browse the internal structure of HEP data files
- Visualize datasets with in-terminal plots

## Getting Started

1. Use the **sidebar** to navigate your data files.
2. Switch tabs to access different functionalities:
   - **Plot**: Visualize your datasets